@@ -1,12 +1,12 @@
-from ConversationAgent import Stage, Agent, __USER_TEXT__, MultiAgent, StageType
-from ConversationAgent.ConversationAgent.jieba_zh.analyse import tfidf
+from . import Stage, Agent, __USER_TEXT__, MultiAgent, StageType
+from .jieba_zh.analyse import tfidf
 import re
 
 __RE_STAGE__ = "__RE_STAGE__"
 __QA_STAGE__ = "__QA_STAGE__"
 __SWITCH_STAGE__ = StageType.SWITCH
 
-from ConversationAgent.ConversationAgent.nlp_tool import similar
+from .nlp_tool import similar
 
 
 class QAStage(Stage):
